Documentation
¶
Index ¶
- Constants
- Variables
- func GetMaccPerms() map[string][]string
- func NewAccNonceHandler(ak auth.AccountKeeper) sdk.AccNonceHandler
- func NewDefaultGenesisState() simapp.GenesisState
- func NewEvmSysContractAddressHandler(ak *evm.Keeper) sdk.EvmSysContractAddressHandler
- func NewGetGasConfigHandler(pk params.Keeper) sdk.GetGasConfigHandler
- func NewUpdateCMTxNonceHandler() sdk.UpdateCMTxNonceHandler
- func PreRun(ctx *server.Context, cmd *cobra.Command) error
- func RepairState(ctx *server.Context, onStart bool)
- type ElapsedTimeInfos
- type OKBChainApp
- func (app *OKBChainApp) BeginBlock(req abci.RequestBeginBlock) (res abci.ResponseBeginBlock)
- func (app *OKBChainApp) BeginBlocker(ctx sdk.Context, req abci.RequestBeginBlock) abci.ResponseBeginBlock
- func (app *OKBChainApp) Codec() *codec.Codec
- func (o *OKBChainApp) CollectUpgradeModules(m *module.Manager) (map[int64]*upgradetypes.HeightTasks, map[string]params.ParamSet, ...)
- func (app *OKBChainApp) Commit(req abci.RequestCommit) abci.ResponseCommit
- func (app *OKBChainApp) DeliverRealTx(req abci.TxEssentials) (res abci.ResponseDeliverTx)
- func (app *OKBChainApp) DeliverTx(req abci.RequestDeliverTx) (res abci.ResponseDeliverTx)
- func (app *OKBChainApp) EndBlock(req abci.RequestEndBlock) (res abci.ResponseEndBlock)
- func (app *OKBChainApp) EndBlocker(ctx sdk.Context, req abci.RequestEndBlock) abci.ResponseEndBlock
- func (app *OKBChainApp) ExportAppStateAndValidators(forZeroHeight bool, jailWhiteList []string) (appState json.RawMessage, validators []tmtypes.GenesisValidator, err error)
- func (app *OKBChainApp) GetKey(storeKey string) *sdk.KVStoreKey
- func (app *OKBChainApp) GetSubspace(moduleName string) params.Subspace
- func (app *OKBChainApp) InitChainer(ctx sdk.Context, req abci.RequestInitChain) abci.ResponseInitChain
- func (app *OKBChainApp) InitUpgrade(ctx sdk.Context)
- func (app *OKBChainApp) LoadHeight(height int64) error
- func (app *OKBChainApp) LoadStartVersion(height int64) error
- func (app *OKBChainApp) Marshal() *codec.CodecProxy
- func (app *OKBChainApp) ModuleAccountAddrs() map[string]bool
- func (app *OKBChainApp) Name() string
- func (app *OKBChainApp) PreDeliverRealTx(req []byte) (res abci.TxEssentials)
- func (app *OKBChainApp) RegisterTxService(clientCtx cliContext.CLIContext)
- func (app *OKBChainApp) SetOption(req abci.RequestSetOption) (res abci.ResponseSetOption)
- func (app *OKBChainApp) SimulationManager() *module.SimulationManager
- type Option
- type SchemaConfig
- type SetupOption
Constants ¶
const ( FlagStartHeight string = "start-height" FlagEnableRepairState string = "enable-repair-state" )
const (
Elapsed = "elapsed"
)
Variables ¶
var ( // DefaultCLIHome sets the default home directories for the application CLI DefaultCLIHome = os.ExpandEnv(system.ClientHome) // DefaultNodeHome sets the folder where the applcation data and configuration will be stored DefaultNodeHome = os.ExpandEnv(system.ServerHome) // ModuleBasics defines the module BasicManager is in charge of setting up basic, // non-dependant module elements, such as codec registration // and genesis verification. ModuleBasics = module.NewBasicManager( auth.AppModuleBasic{}, supply.AppModuleBasic{}, genutil.AppModuleBasic{}, bank.AppModuleBasic{}, staking.AppModuleBasic{}, mint.AppModuleBasic{}, distr.AppModuleBasic{}, gov.NewAppModuleBasic( paramsclient.ProposalHandler, paramsclient.UpgradeProposalHandler, distr.CommunityPoolSpendProposalHandler, distr.ChangeDistributionTypeProposalHandler, distr.WithdrawRewardEnabledProposalHandler, distr.RewardTruncatePrecisionProposalHandler, evmclient.ManageContractDeploymentWhitelistProposalHandler, evmclient.ManageContractBlockedListProposalHandler, evmclient.ManageContractMethodGuFactorProposalHandler, evmclient.ManageContractMethodBlockedListProposalHandler, evmclient.ManageSysContractAddressProposalHandler, evmclient.ManageContractByteCodeProposalHandler, govclient.ManageTreasuresProposalHandler, govclient.ExtraProposalHandler, erc20client.TokenMappingProposalHandler, erc20client.ProxyContractRedirectHandler, erc20client.ContractTemplateProposalHandler, client.UpdateClientProposalHandler, fsclient.FeeSplitSharesProposalHandler, wasmclient.MigrateContractProposalHandler, wasmclient.UpdateContractAdminProposalHandler, wasmclient.PinCodesProposalHandler, wasmclient.UnpinCodesProposalHandler, wasmclient.UpdateDeploymentWhitelistProposalHandler, wasmclient.UpdateWASMContractMethodBlockedListProposalHandler, wasmclient.GetCmdExtraProposal, stakingclient.ProposeValidatorProposalHandler, ), params.AppModuleBasic{}, crisis.AppModuleBasic{}, slashing.AppModuleBasic{}, evidence.AppModuleBasic{}, upgrade.AppModuleBasic{}, evm.AppModuleBasic{}, token.AppModuleBasic{}, infura.AppModuleBasic{}, capabilityModule.AppModuleBasic{}, ibc.AppModuleBasic{}, ibctransfer.AppModuleBasic{}, erc20.AppModuleBasic{}, wasm.AppModuleBasic{}, feesplit.AppModuleBasic{}, ica.AppModuleBasic{}, ibcfee.AppModuleBasic{}, icamauth.AppModuleBasic{}, ) FlagGolangMaxThreads string = "golang-max-threads" )
var (
DefaultElapsedSchemas string
)
Functions ¶
func GetMaccPerms ¶
GetMaccPerms returns a copy of the module account permissions
func NewAccNonceHandler ¶
func NewAccNonceHandler(ak auth.AccountKeeper) sdk.AccNonceHandler
func NewDefaultGenesisState ¶
func NewDefaultGenesisState() simapp.GenesisState
NewDefaultGenesisState generates the default state for the application.
func NewEvmSysContractAddressHandler ¶
func NewEvmSysContractAddressHandler(ak *evm.Keeper) sdk.EvmSysContractAddressHandler
func NewGetGasConfigHandler ¶ added in v0.1.6
func NewGetGasConfigHandler(pk params.Keeper) sdk.GetGasConfigHandler
func NewUpdateCMTxNonceHandler ¶ added in v0.1.2
func NewUpdateCMTxNonceHandler() sdk.UpdateCMTxNonceHandler
func RepairState ¶
Types ¶
type ElapsedTimeInfos ¶
type ElapsedTimeInfos struct {
// contains filtered or unexported fields
}
func (*ElapsedTimeInfos) AddInfo ¶
func (e *ElapsedTimeInfos) AddInfo(key string, info string)
func (*ElapsedTimeInfos) Dump ¶
func (e *ElapsedTimeInfos) Dump(input interface{})
func (*ElapsedTimeInfos) GetElapsedTime ¶
func (e *ElapsedTimeInfos) GetElapsedTime() int64
func (*ElapsedTimeInfos) SetElapsedTime ¶
func (e *ElapsedTimeInfos) SetElapsedTime(elapsedTime int64)
type OKBChainApp ¶
type OKBChainApp struct {
*bam.BaseApp
// keepers
AccountKeeper auth.AccountKeeper
BankKeeper bank.Keeper
SupplyKeeper supply.Keeper
StakingKeeper staking.Keeper
SlashingKeeper slashing.Keeper
MintKeeper mint.Keeper
DistrKeeper distr.Keeper
GovKeeper gov.Keeper
CrisisKeeper crisis.Keeper
UpgradeKeeper upgrade.Keeper
ParamsKeeper params.Keeper
EvidenceKeeper evidence.Keeper
EvmKeeper *evm.Keeper
TokenKeeper token.Keeper
WasmKeeper wasm.Keeper
WasmPermissionKeeper wasm.ContractOpsKeeper
InfuraKeeper infura.Keeper
FeeSplitKeeper feesplit.Keeper
// ibc
ScopedIBCKeeper capabilitykeeper.ScopedKeeper
ScopedTransferKeeper capabilitykeeper.ScopedKeeper
ScopedIBCMockKeeper capabilitykeeper.ScopedKeeper
TransferKeeper ibctransferkeeper.Keeper
CapabilityKeeper *capabilitykeeper.Keeper
IBCKeeper *ibc.Keeper // IBC Keeper must be a pointer in the app, so we can SetRouter on it correctly
IBCFeeKeeper ibcfeekeeper.Keeper
Erc20Keeper erc20.Keeper
ICAMauthKeeper icamauthkeeper.Keeper
ICAControllerKeeper icacontrollerkeeper.Keeper
ICAHostKeeper icahostkeeper.Keeper
VMBridgeKeeper *vmbridge.Keeper
WasmHandler wasmkeeper.HandlerOption
// contains filtered or unexported fields
}
OKBChainApp implements an extended ABCI application. It is an application that may process transactions through Ethereum's EVM running atop of Tendermint consensus.
func NewOKBChainApp ¶
func NewOKBChainApp( logger log.Logger, db dbm.DB, traceStore io.Writer, loadLatest bool, skipUpgradeHeights map[int64]bool, invCheckPeriod uint, baseAppOptions ...func(*bam.BaseApp), ) *OKBChainApp
NewOKBChainApp returns a reference to a new initialized OKBChain application.
func Setup ¶
func Setup(isCheckTx bool, options ...Option) *OKBChainApp
Setup initializes a new OKBChainApp. A Nop logger is set in OKBChainApp.
func (*OKBChainApp) BeginBlock ¶
func (app *OKBChainApp) BeginBlock(req abci.RequestBeginBlock) (res abci.ResponseBeginBlock)
BeginBlock implements the Application interface
func (*OKBChainApp) BeginBlocker ¶
func (app *OKBChainApp) BeginBlocker(ctx sdk.Context, req abci.RequestBeginBlock) abci.ResponseBeginBlock
BeginBlocker updates every begin block
func (*OKBChainApp) Codec ¶
func (app *OKBChainApp) Codec() *codec.Codec
Codec returns OKBChain's codec.
NOTE: This is solely to be used for testing purposes as it may be desirable for modules to register their own custom testing types.
func (*OKBChainApp) CollectUpgradeModules ¶
func (o *OKBChainApp) CollectUpgradeModules(m *module.Manager) (map[int64]*upgradetypes.HeightTasks, map[string]params.ParamSet, []types.StoreFilter, []types.StoreFilter, []types.VersionFilter)
func (*OKBChainApp) Commit ¶
func (app *OKBChainApp) Commit(req abci.RequestCommit) abci.ResponseCommit
Commit implements the Application interface
func (*OKBChainApp) DeliverRealTx ¶
func (app *OKBChainApp) DeliverRealTx(req abci.TxEssentials) (res abci.ResponseDeliverTx)
func (*OKBChainApp) DeliverTx ¶
func (app *OKBChainApp) DeliverTx(req abci.RequestDeliverTx) (res abci.ResponseDeliverTx)
func (*OKBChainApp) EndBlock ¶
func (app *OKBChainApp) EndBlock(req abci.RequestEndBlock) (res abci.ResponseEndBlock)
EndBlock implements the Application interface
func (*OKBChainApp) EndBlocker ¶
func (app *OKBChainApp) EndBlocker(ctx sdk.Context, req abci.RequestEndBlock) abci.ResponseEndBlock
EndBlocker updates every end block
func (*OKBChainApp) ExportAppStateAndValidators ¶
func (app *OKBChainApp) ExportAppStateAndValidators( forZeroHeight bool, jailWhiteList []string, ) (appState json.RawMessage, validators []tmtypes.GenesisValidator, err error)
ExportAppStateAndValidators exports the state of the application for a genesis file.
func (*OKBChainApp) GetKey ¶
func (app *OKBChainApp) GetKey(storeKey string) *sdk.KVStoreKey
GetKey returns the KVStoreKey for the provided store key.
NOTE: This is solely to be used for testing purposes.
func (*OKBChainApp) GetSubspace ¶
func (app *OKBChainApp) GetSubspace(moduleName string) params.Subspace
GetSubspace returns a param subspace for a given module name.
NOTE: This is solely to be used for testing purposes.
func (*OKBChainApp) InitChainer ¶
func (app *OKBChainApp) InitChainer(ctx sdk.Context, req abci.RequestInitChain) abci.ResponseInitChain
InitChainer updates at chain initialization
func (*OKBChainApp) InitUpgrade ¶ added in v0.1.2
func (app *OKBChainApp) InitUpgrade(ctx sdk.Context)
func (*OKBChainApp) LoadHeight ¶
func (app *OKBChainApp) LoadHeight(height int64) error
LoadHeight loads state at a particular height
func (*OKBChainApp) LoadStartVersion ¶
func (app *OKBChainApp) LoadStartVersion(height int64) error
func (*OKBChainApp) Marshal ¶
func (app *OKBChainApp) Marshal() *codec.CodecProxy
func (*OKBChainApp) ModuleAccountAddrs ¶
func (app *OKBChainApp) ModuleAccountAddrs() map[string]bool
ModuleAccountAddrs returns all the app's module account addresses.
func (*OKBChainApp) PreDeliverRealTx ¶
func (app *OKBChainApp) PreDeliverRealTx(req []byte) (res abci.TxEssentials)
func (*OKBChainApp) RegisterTxService ¶
func (app *OKBChainApp) RegisterTxService(clientCtx cliContext.CLIContext)
func (*OKBChainApp) SetOption ¶
func (app *OKBChainApp) SetOption(req abci.RequestSetOption) (res abci.ResponseSetOption)
func (*OKBChainApp) SimulationManager ¶
func (app *OKBChainApp) SimulationManager() *module.SimulationManager
SimulationManager implements the SimulationApp interface
type SchemaConfig ¶
type SchemaConfig struct {
// contains filtered or unexported fields
}
type SetupOption ¶
type SetupOption struct {
// contains filtered or unexported fields
}
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
crypto
|
|
|
Package rpc contains RPC handler methods, namespaces and utilities to start Ethermint's Web3-compatible JSON-RPC server.
|
Package rpc contains RPC handler methods, namespaces and utilities to start Ethermint's Web3-compatible JSON-RPC server. |